@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c 11293 2009-02-17 09:05:47Z callum $ */
+/* $Id: gweather-pref.c 11399 2009-03-21 02:12:11Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -344,13 +344,13 @@ auto_update_toggled (GtkToggleButton *button, GWeatherPref *pref)
     if (gw_applet->suncalc_timeout_tag > 0)
         g_source_remove(gw_applet->suncalc_timeout_tag);
     if (gw_applet->gweather_pref.update_enabled) {
-        gw_applet->timeout_tag = g_timeout_add (
-				gw_applet->gweather_pref.update_interval * 1000,
+        gw_applet->timeout_tag = g_timeout_add_seconds (
+				gw_applet->gweather_pref.update_interval,
 				timeout_cb, gw_applet);
 	nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
 	if (nxtSunEvent >= 0)
-	    gw_applet->suncalc_timeout_tag = g_timeout_add (
-	    						nxtSunEvent * 1000,
+	    gw_applet->suncalc_timeout_tag = g_timeout_add_seconds (
+	    						nxtSunEvent,
 							suncalc_timeout_cb,
 							gw_applet);
     }
@@ -548,7 +548,7 @@ update_interval_changed (GtkSpinButton *button, GWeatherPref *pref)
         g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
         gw_applet->timeout_tag =  
-        	g_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+        	g_timeout_add_seconds (gw_applet->gweather_pref.update_interval,
                                  timeout_cb, gw_applet);
 }
 
@@ -710,6 +710,8 @@ find_entry_changed (GtkEditable *entry, GWeatherPref *pref)
 	tree = GTK_TREE_VIEW (pref->priv->tree);
 	model = gtk_tree_view_get_model (tree);
 
+	g_return_if_fail (model != NULL);
+
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
 	gtk_tree_model_get_iter_first (model, &iter);
 
